<?php

namespace Acms\Services\Login;

use Acms\Services\Facades\Common;
use Acms\Services\Login\Exceptions\BadRequestException;
use Acms\Services\Login\Exceptions\ExpiredException;
use ACMS_RAM;

class Helper
{
    /**
     * @param array $context
     * @param int $lifetime
     * @return string
     */
    public function createTimedLinkParams($context, $lifetime)
    {
        $salt = Common::genPass(32); // 事前共有鍵
        $context['expire'] = REQUEST_TIME + $lifetime; // 有効期限
        $context = acmsSerialize($context);
        $prk = hash_hmac('sha256', PASSWORD_SALT_1, $salt);
        $derivedKey = hash_hmac('sha256', $prk, $context);
        $params = http_build_query(array(
            'key' => $derivedKey,
            'salt' => $salt,
            'context' => $context,
        ));
        return $params;
    }

    /**
     * @param string $key
     * @param string $salt
     * @param string $context
     * @return array
     * @throws BadRequestException
     * @throws ExpiredException
     */
    public function validateTimedLinkParams($key, $salt, $context)
    {
        $prk = hash_hmac('sha256', PASSWORD_SALT_1, $salt);
        $derivedKey = hash_hmac('sha256', $prk, $context);
        if (!hash_equals($key, $derivedKey)) {
            throw new BadRequestException('Bad request.');
        }
        $context = acmsUnserialize($context);
        if (!isset($context['expire'])) {
            throw new BadRequestException('Bad request.');
        }
        if (REQUEST_TIME > $context['expire']) {
            throw new ExpiredException('Expired.');
        }
        return $context;
    }

    /**
     * ログインしている場合、権限のCookieを追加
     *
     * @param int $uid
     * @return void
     */
    public function addExtraLoggedInCookie($uid)
    {
        if (config('extra_logged_in_cookie') !== 'on') {
            return;
        }
        $name = config('extra_logged_in_cookie_name', 'acms-logged-in');
        acmsSetCookie($name, ACMS_RAM::userAuth($uid));
    }

    /**
     * ログインしている時、追加されるCookieを削除
     *
     * @return void
     */
    public function removeExtraLoggedInCookie()
    {
        $name = config('extra_logged_in_cookie_name', 'acms-logged-in');
        acmsSetCookie($name, null, REQUEST_TIME - 1);
    }
}
